@@ -41,6 +41,8 @@
 
 #define ATTICA_DECL_DEPRECATED_TEXT(text) __attribute__ ((__deprecated__(text)))
 
+#define ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, patch) ((major<<16)|(minor<<8)|(patch))
+
 /* Take any defaults from group settings */
 #if !defined(ATTICA_NO_DEPRECATED) && !defined(ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #  ifdef KF_NO_DEPRECATED
@@ -84,7 +86,7 @@
 #define ATTICA_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef ATTICA_NO_DEPRECATED
-#  define ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x57100
+#  define ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT 0x54200
 #endif
 #ifdef ATTICA_NO_DEPRECATED_WARNINGS
 #  define ATTICA_DEPRECATED_WARNINGS_SINCE 0
@@ -94,7 +96,7 @@
 #  ifdef ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define ATTICA_DEPRECATED_WARNINGS_SINCE ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define ATTICA_DEPRECATED_WARNINGS_SINCE 0x57100
+#    define ATTICA_DEPRECATED_WARNINGS_SINCE 0x54200
 #  endif
 #endif
 
@@ -103,7 +105,7 @@
 #endif
 
 #ifdef ATTICA_DEPRECATED
-#  define ATTICA_ENABLE_DEPRECATED_SINCE(major, minor) (((major<<16)|(minor<<8)) > ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT)
+#  define ATTICA_ENABLE_DEPRECATED_SINCE(major, minor) (ECM_GENERATEEXPORTHEADER_VERSION_VALUE(major, minor, 0) > ATTICA_DISABLE_DEPRECATED_BEFORE_AND_AT)
 #else
 #  define ATTICA_ENABLE_DEPRECATED_SINCE(major, minor) 0
 #endif
@@ -128,13 +130,5 @@
 #define ATTICA_DEPRECATED_VERSION_0(minor, text)      ATTICA_DEPRECATED_VERSION_0_##minor(text)
 #define ATTICA_DEPRECATED_VERSION_5(minor, text)      ATTICA_DEPRECATED_VERSION_5_##minor(text)
 #define ATTICA_DEPRECATED_VERSION(major, minor, text) ATTICA_DEPRECATED_VERSION_##major(minor, "Since "#major"."#minor". " text)
-#define ATTICA_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) ATTICA_DEPRECATED_VERSION_##major(minor, "Since "#textmajor"."#textminor". " text)
-#if defined(__cpp_enumerator_attributes) && __cpp_enumerator_attributes >= 201411
-#  define ATTICA_ENUMERATOR_DEPRECATED_VERSION(major, minor, text) ATTICA_DEPRECATED_VERSION(major, minor, text)
-#  define ATTICA_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text) ATTICA_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#else
-#  define ATTICA_ENUMERATOR_DEPRECATED_VERSION(major, minor, text)
-#  define ATTICA_ENUMERATOR_DEPRECATED_VERSION_BELATED(major, minor, textmajor, textminor, text)
-#endif
 
 #endif /* ATTICA_EXPORT_H */
